#
# spec file for package libbacktrace
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname 0
Name:           libbacktrace
Version:        1.0+git20231130
Release:        bp155.2.1
Summary:        Backtrace C library
License:        BSD-3-Clause
URL:            https://github.com/ianlancetaylor/libbacktrace
Source0:        %{name}-%{version}.tar.gz
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libunwind)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(zlib)

%description
A C library that may be linked into a C/C++ program to produce symbolic backtraces.

%package -n %{name}%{soname}
Summary:        Backtrace C library

%description -n %{name}%{soname}
This is a C library that may be linked into a C/C++ program to produce symbolic backtraces.

%package devel
Summary:        Development files for %{name}
Requires:       %{name}%{soname} = %{version}

%description devel
The %{name}-devel package contains libraries and header files for developing applications that use %{name}.

%prep
%autosetup

%build
autoreconf -fiv
%configure \
  --disable-static \
  --enable-shared \
  --with-system-libunwind \
  --enable-silent-rules
%make_build

%check
# btest_dwz fails
%make_build check ||:

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%ldconfig_scriptlets -n %{name}%{soname}

%files -n %{name}%{soname}
%doc README.md
%license LICENSE
%{_libdir}/*.so.*

%files devel
%{_includedir}/*.h
%{_libdir}/*.so

%changelog
* Fri Feb 23 2024 Richard Rahl <rrahl0@proton.me>
- switch over the devel packages to pkgconfig
* Wed Feb 21 2024 Martin Pluskal <mpluskal@suse.com>
- Use system libunwind
- Run internal testsuite during build
* Mon Feb 19 2024 Martin Pluskal <mpluskal@suse.com>
- Cleanup spec file
- Switch _service to obs_scm
* Sat Feb 17 2024 Richard Rahl <rrahl0@proton.me>
- fix description, so rpmlint doesn't complain
* Fri Dec  1 2023 marec@detebe.org
- Update to version 1.0_git20231130:
  * libbacktrace: support ASLR on Windows
  * libbacktrace: call GetModuleFileNameA on Windows
* Fri Aug  4 2023 marec@detebe.org
- Update to version 1.0_git20230803:
  * [libbacktrace] fix up broken test
* Tue Aug  1 2023 marec@detebe.org
- Update to version 1.0_git20230731:
  * libbacktrace: look for _pgmptr on Windows
* Wed Mar 29 2023 marec@detebe.org
- Update to version 1.0_git20230328:
  * libbacktrace: minor fixes for zstd decompression
  * libbacktrace: change PC variables from uint64_t to uintptr_t
* Sat Jan  7 2023 marec@detebe.org
- Update to version 1.0_git20230106:
  * libbacktrace: don't run --build-id tests if it is not supported
* Sat Dec 17 2022 marec@detebe.org
- Update to version 1.0_git20221216:
  * libbacktrace: unpack literals into output buffer
* Sat Dec 10 2022 marec@detebe.org
- Update to version 1.0_git20221209:
  * libbacktrace: rewrite and simplify main zstd loop
* Fri Dec  9 2022 marec@detebe.org
- Update to version 1.0_git20221207:
  * libbacktrace: support zstd decompression
* Sat Jul  9 2022 marec@detebe.org
- Update to version 1.0_git20220708:
  * libbacktrace: check for sys/link.h
* Fri Jul  8 2022 marec@detebe.org
- Update to version 1.0_git20220707:
  * libbacktrace: don't exit Mach-O dyld library loop on one failure
  * libbacktrace: don't let "make clean" remove allocfail.sh
  * libbacktrace: replace fgrep with grep in configure script
* Wed Apr  6 2022 marec@detebe.org
- Update to version 1.0_git20220405:
  * libbacktrace: don't skip initial aligned byte in uncompressed block
* Thu Feb 17 2022 marec@detebe.org
- Update to version 1.0_git20220217:
  * libbacktrace: gather address ranges from skeleton units
  * libbacktrace: initialize DWARF 5 fields of unit
  * configury: support --disable-werror
* Wed Jan 19 2022 marec@detebe.org
- Update to version 1.0_git20220118:
  * configury: update to recent versions
* Sun May 30 2021 marec@detebe.org
- Update to version 1.0_git20210529:
  * config/override.m4: don't require exactly autoconf 2.69
* Wed Mar  3 2021 marec@detebe.org
- Update to version 1.0_git20210302:
  * libbacktrace: don't special case file 0
  * libbacktrace: pass -1 to error callback for unrecognized DWARF
* Fri Feb 12 2021 marec@detebe.org
- Update to version 1.0_git20210211:
  * libbacktrace: check for objcopy --add-gnu-debuglink using --help
* Tue Jan 19 2021 marec@detebe.org
- Update to version 1.0_git20210118:
  * libbacktrace: don't fail tests if dwz fails
  * libbacktrace: use correct directory/filename for DWARF 5
  * Update copyright years.
* Sat Dec  5 2020 marec@detebe.org
- Update to version 1.0_git20201204:
  * libbacktrace: correct buffer overflow tests
* Mon Oct 26 2020 marec@detebe.org
- Update to version 1.0_git20201026:
  * libbacktrace: update README
* Sat Oct 24 2020 marec@detebe.org
- Update to version 1.0_git20201020:
  * libbacktrace: use __attribute__((__fallthrough__))
* Thu Oct  1 2020 marec@detebe.org
- Update to version 1.0_git20200930:
  * libbacktrace: replace Tom Sawyer with Opticks
* Tue Sep 29 2020 marec@detebe.org
- Update to version 1.0_git20200928:
  * libbacktrace/ChangeLog:         PR libbacktrace/97082         * Makefile.am (check_DATA): Add mtest.dSYM if USE_DSYMUTIL.         * Makefile.in: Regenerate.
  * libbacktrace: only run dsymutil with Mach-O
* Mon Sep 28 2020 marec@detebe.org
- Update to version 1.0_git20200927:
  * libbacktrace: handle pc == low correctly
  * libbacktrace: use ELF symbol table if no debug info available
  * libbacktrace, Mach-O : Support PowerPC archs.
  * libbacktrace: support MiniDebugInfo
  * libbacktrace: don't strip leading underscore on 64-bit PE
  * libbacktrace: fetch executable path on macOS
  * libbacktrace: avoid ambiguous binary search
  * libbacktrace: fix tipo in comment
  * libbacktrace: correct memory lengths in Mach-O dsym support
  * libbacktrace: correctly swap Mach-O 32-bit file offset
  * libbacktrace: only match magic number at start of line
  * libbacktrace: add Mach-O 64-bit FAT support
  * libbacktrace: test linker support for DWARF 5
* Thu May 14 2020 marec@detebe.org
- Update to version 1.0_git20200513:
  * libbacktrace: mark test_large parameter unused in ztest.c
  * libbacktrace: treat EACCESS like ENOENT
* Mon May 11 2020 marec@detebe.org
- Update to version 1.0_git20200511:
  * libbacktrace: declare getpagesize if necessary
* Sun May 10 2020 marec@detebe.org
- Update to version 1.0_git20200509:
  * libbacktrace: don't crash if ELF file has no sections
* Wed Feb 19 2020 marec@detebe.org
- Update to version 1.0_git20200219:
  * libbacktrace: don't free ELF strtab if error occurs after saving syminfo
* Wed Feb 19 2020 marec@detebe.org
- Update to version 1.0_git20200218:
  * libbacktrace: add preliminary Mach-O support
  * libbacktrace: always pass -g when compiling test code
  * Update copyright years.
  * libbacktrace: update to current libgo test file
  * libbacktrace: support short read
  * libbacktrace: if debug info large or split, read sections individually
  * libbacktrace: support fetching executable name using sysctl
  * libbacktrace: update to current version from GCC trunk
  * config.guess, config.sub: update to latest versions
  * config.guess, config.sub: update to current GCC versions
* Tue Feb 18 2020 marec <marec@detebe.org>
- initial package build
